@@ -1,6 +1,6 @@
 /* hdup.c, a backup program
  *
- * $Id: hdup.c,v 1.102 2004/06/01 12:17:40 miekg Exp $
+ * $Id: hdup.c,v 1.109 2004/10/03 12:57:56 miekg Exp $
  *
  * Copyright (c) 2000-2004, Miek Gieben. All right reserverd.
  *
@@ -123,8 +123,9 @@ backup_local(phost_t host[], int which, struct argument_t *arg)
 		what = (char*)xmalloc(l+10);
 		sprintf(what,"yes (%s, %s)", host[which]->alg, host[which]->keypath);
 		hdup_overview("Encryption", what);
-	} else 
+	} else {
 		hdup_overview("Encryption", "no");
+	}
 
 	/* the exclude list , run this after include -> include + exclude together in overview */
 	hdup_excludelist(host[which],host[0]);
@@ -417,25 +418,35 @@ main (int argc, char *argv[])
 	/* looks a bit difficult, but this wil select gzip by default
 	 * and if not, it will take the default from the hdup.conf
 	 */
+	/* also check if the exe is on the system MG 27 Sept 2004 */
 	if ( host[which]->compression != NULL ) {
-		if (  strncmp (host[which]->compression, "gzip", 4) == 0 ) 
+		if (  strncmp (host[which]->compression, "gzip", 4) == 0 ) {
 			/* ok, found */
 			host[which]->compression    = TAR_GZIP;
-		else if ( strncmp(host[which]->compression, "none", 4) == 0 ) 
+			if (hdup_checkfile(GZIP_PROG) == 0 )
+				FATAL("%s: compression %s %s", host[which]->name, GZIP_PROG, "not found");
+		} else if ( strncmp(host[which]->compression, "none", 4) == 0 ) {
 			host[which]->compression  = TAR_NONE;
-		else if ( strncmp(host[which]->compression, "bzip", 4) == 0 ) 
+		} else if ( strncmp(host[which]->compression, "bzip", 4) == 0 ) {
 			host[which]->compression  = TAR_BZIP;
-		else if ( strncmp(host[which]->compression, "lzop", 4) == 0 ) 
+			if (hdup_checkfile(BZIP_PROG) == 0 )
+				FATAL("%s: compression %s %s", host[which]->name, BZIP_PROG, "not found");
+		} else if ( strncmp(host[which]->compression, "lzop", 4) == 0 ) {
 			host[which]->compression  = TAR_LZOP;
-		else {
+			if (hdup_checkfile(LZOP_PROG) == 0 )
+				FATAL("%s: %s %s", host[which]->name, LZOP_PROG, "not found");
+		} else {
 			/* unknown */
-			FATAL("%s: %s %s",host[which]->name, "Unknown compression: ",host[which]->compression );
+			FATAL("%s: compression %s %s",host[which]->name, "Unknown compression: ",host[which]->compression );
 		}
 	} else {
-		VERBOSE("%s","No compression given, defaulting to: gzip");
+		VVERBOSE("%s","No compression given, defaulting to: gzip");
 		host[which]->compression = TAR_GZIP; /* default */
 		host[0]->compression = TAR_GZIP; /* default */
+		if (hdup_checkfile(GZIP_PROG) == 0 )
+			FATAL("%s: compression %s %s", host[which]->name, GZIP_PROG, "not found");
 	}
+	
 
 	if ( host[which]->prerun == NULL )
 		host[which]->prerun = host[0]->prerun;
@@ -444,7 +455,7 @@ main (int argc, char *argv[])
 
 	if ( host[which]->user == NULL ) {
 		if ( host[0]->user == NULL ) {
-			VERBOSE("%s %s","No user given, defaulting to:", DEF_USER);
+			VVERBOSE("%s %s","No user given, defaulting to:", DEF_USER);
 			host[which]->user = DEF_USER;
 		} else
 			host[which]->user = host[0]->user;
@@ -466,7 +477,7 @@ main (int argc, char *argv[])
 	/* ssh or whatever (rsync?) */
 	if ( host[which]->proto == NULL ) {
 		if ( host[0]->proto == NULL ) {
-			VERBOSE("%s %s","No protocol path given, defaulting to:",DEFAULT_PROTO);
+			VVERBOSE("%s %s","No protocol path given, defaulting to:",DEFAULT_PROTO);
 			host[which]->proto = DEFAULT_PROTO;
 		} else 
 			host[which]->proto = host[0]->proto;
@@ -495,24 +506,33 @@ main (int argc, char *argv[])
 	/* tar */
 	if ( host[which]->tar == NULL ) {
 		if ( host[0]->tar ==  NULL ) {
-			VERBOSE("%s %s", "No tar path given, defaulting to:",TAR);
+			VVERBOSE("%s %s", "No tar path given, defaulting to:",TAR);
 			host[which]->tar = TAR;
 		} else 
 			host[which]->tar = host[0]->tar;
 	}
+
+	/* tar options */
+	if ( host[which]->tar_conf_opt == NULL ) {
+		if ( host[0]->tar_conf_opt ==  NULL ) {
+			VVERBOSE("%s %s", "No tar option given, defaulting to:",TAR_CONF_OPT);
+			host[which]->tar_conf_opt = TAR_CONF_OPT;
+		} else
+			host[which]->tar_conf_opt = host[0]->tar_conf_opt;
+	}
 	/* find */
 	if ( host[which]->find == NULL ) {
 		if ( host[0]->find == NULL ) {
 			/* don't warn unneeded */
 			if ( host[which]->include[0] != NULL)
-				VERBOSE("%s %s","No find path given, defaulting to:",FIND);
+				VVERBOSE("%s %s","No find path given, defaulting to:",FIND);
 			host[which]->find = FIND;
 		} else 
 			host[which]->find = host[0]->find;
 	}
 	if ( host[which]->mcrypt == NULL ) {
 		if ( host[0]->mcrypt ==  NULL ) {
-			VERBOSE("%s %s", "No mcrypt path given, defaulting to:",MCRYPT);
+			VVERBOSE("%s %s", "No mcrypt path given, defaulting to:",MCRYPT);
 			host[which]->mcrypt = MCRYPT;
 		} else 
 			host[which]->mcrypt = host[0]->mcrypt;
@@ -520,7 +540,7 @@ main (int argc, char *argv[])
 
 	if ( host[which]->gpg == NULL ) {
 		if ( host[0]->gpg ==  NULL ) {
-			VERBOSE("%s %s", "No gpg path given, defaulting to:",GPG);
+			VVERBOSE("%s %s", "No gpg path given, defaulting to:",GPG);
 			host[which]->gpg = GPG;
 		} else 
 			host[which]->gpg = host[0]->gpg;
