@@ -1,7 +1,7 @@
 /* hduplib.c
  * lib with some general function handy for hdup
  * 
- * $Id: hduplib.c,v 1.90 2004/06/23 13:20:07 miekg Exp $
+ * $Id: hduplib.c,v 1.95 2004/09/27 07:42:38 miekg Exp $
  * 
  * Copyright:
  *
@@ -593,7 +593,7 @@ int hdup_system(char * command) {
 	my_command = strdup(command);
 
 	if ( quiet > 1 ) {
-		realloc(my_command, strlen(MUTE) + 2);
+		my_command = xrealloc(my_command, strlen(MUTE) + 2);
 		strcat(my_command,MUTE);
 	}
 
@@ -817,7 +817,6 @@ char * hdup_lastname (char * filepath) {
 
 int hdup_checkfile (char *filepath) {
 	/*
-	 * returns * 1: file
 	 * doesn't do globbing
 	 */
 
@@ -1348,6 +1347,7 @@ int hdup_getheader(pheader_t head, FILE *stream) {
 	hdup_readword(head->prot_name, stream, strlen(PROT_NAME));
 	hdup_readword(head->prot_ver, stream, strlen(PROT_NAME));
 	hdup_readword(head->hostname, stream, MAXPATHLEN);
+	/* here 1 less the in hdup_fillheader */
 	hdup_readword(head->scheme, stream, 8);
 	hdup_readword(head->date, stream, 11);
 	hdup_readword(head->compression, stream, 5);
@@ -1369,11 +1369,11 @@ int hdup_fillheader(pheader_t head, phost_t host, int s, char *extractdir) {
 	head->prot_ver  = (char*) xmalloc( strlen(PROT_VER) + 1);
 	head->prot_name = (char*) xmalloc( strlen(PROT_NAME) + 1 );
 	head->hostname   = (char *)xmalloc(MAXPATHLEN);
-	head->scheme = (char *)xmalloc(8);  
-	head->date   = (char *)xmalloc(11);
-	head->compression = (char *)xmalloc(5);
-	head->encryption = (char *)xmalloc(1);
-	head->extractdir = (char *)xmalloc(MAXPATHLEN);
+	head->scheme = (char *)xmalloc(9);  
+	head->date   = (char *)xmalloc(12);
+	head->compression = (char *)xmalloc(6);
+	head->encryption = (char *)xmalloc(2);
+	head->extractdir = (char *)xmalloc(MAXPATHLEN + 1);
 
 	/* put the stuff in there */
 	head->prot_name = PROT_NAME;
@@ -1382,6 +1382,8 @@ int hdup_fillheader(pheader_t head, phost_t host, int s, char *extractdir) {
 	head->scheme = scheme[s];
 	head->date   = host->date;
 	head->compression = host->compression;
+
+	
 	if ( host->alg == NULL ) 
 		head->encryption = "n";
 	else 
@@ -1391,6 +1393,7 @@ int hdup_fillheader(pheader_t head, phost_t host, int s, char *extractdir) {
 		strncpy(head->extractdir,extractdir,MAXPATHLEN);
 	else 
 		head->extractdir="\0";
+
 	return 0;
 }
 
@@ -1600,6 +1603,20 @@ xmalloc(size_t size)
 	return x;
 }
 
+void *
+xrealloc(void *p, size_t size)
+{
+	/* alloc some memory, exit if this fails */
+	void *x;
+
+	x = realloc(p, size);
+
+	if (x == NULL) 
+		FATAL("%s","Memory allocation failure");
+
+	return x;
+}
+
 int usage() {
 	fprintf(stdout,"Usage:\n");
 	fprintf(stdout,"    hdup [ OPTION ] SCHEME HOST [ @USER@REMOTE_HOST ] (1st format)\n");
