@@ -1,6 +1,6 @@
 /* hduptarlib.c, do all the tar things here
  *
- * $Id: hduptarlib.c,v 1.50 2004/06/23 17:31:52 miekg Exp $
+ * $Id: hduptarlib.c,v 1.55 2004/09/25 19:39:16 miekg Exp $
  *
  * Copyright:
  *
@@ -44,7 +44,12 @@ int hdup_dountar(phost_t host, struct argument_t * arg, char *restore) {
 	if ( host->remote == NULL ) {
 		/* stay local */
 		if (hdup_compression(restore) == CRYPT ) {
-			if (host->alg == NULL ) { VERBOSE("%s", "Archive appears to be encrypted - skipping"); return 1 ; }
+			/* is something is encrpypted I must have 
+			 * the decryption key */
+			if (host->alg == NULL ) { 
+				VERBOSE("%s", "Archive appears to be encrypted - skipping"); 
+				return 1 ; 
+			}
 
 			decrypt = setup_decryptcmd(host);
 
@@ -57,26 +62,21 @@ int hdup_dountar(phost_t host, struct argument_t * arg, char *restore) {
 			out = tar;
 		}
 	} else {
-		/* move to the other side */
+		/* untar from remote sideside */
 		/* allocate space, here and only here */
 		header = (pheader_t) xmalloc (sizeof(header_t));
 		hdup_fillheader(header, host, RESTORE, arg->extractdir);
 		ssh = setup_transportcmd(host);
 		if (hdup_compression(restore) == CRYPT ) {
-			if (host->alg == NULL ) { VERBOSE("%s", "Archive appears to be encrypted - skipping"); return 1; }
-
-			decrypt = setup_decryptcmd(host);
-
-			out = (char*)xmalloc(strlen(decrypt) + strlen(ssh) + 4);
-
-			sprintf(out,"%s | %s", decrypt, ssh);
-		} else {
-			out = ssh;
+			/* there is no special access function... ugly.. */
+			VERBOSE("%s", "Archive is encrypted - adding to header"); 
+			header->encryption = "y";
 		}
+		out = ssh;
 	}
+
 	/* out contains the OTHER side of the pipe, in is the archive we're dealing 
-	 * with */
-	/* everything is setup, now check for compression stuff */
+	 * with everything is setup, now check for compression stuff */
 	if ( hdup_chunk(restore) == SPLIT ) {
 		/* oh no, split up archive */
 		/* remote or local doesn't matter */
@@ -359,6 +359,8 @@ int stream2pipe(FILE *in, char *out, pheader_t head) {
 	FILE *pout;
 	int c; int stat;
 
+	fflush(stdin);
+	fflush(stdout);
 	pout = popen(out,"w");
 
 	if ( pout == NULL ) { 
@@ -372,9 +374,10 @@ int stream2pipe(FILE *in, char *out, pheader_t head) {
 		return 1;
 	}
 
-	if ( head != NULL ) 
+	if ( head != NULL ) {
 		/* print the header first */
 		hdup_putheader(head, pout);
+	}
 
 	/* Processing loop */
 	/* if nothing is waiting on the other side, a SIGPIPE is thrown */
@@ -565,6 +568,7 @@ char * setup_tarcmd(phost_t host) {
 			LEN(SPARSE) + 2 +
 			LEN("--ignore-failed-read") + compmax_len + 
 			compmax_len + 4 + /* strlen(comp) */
+			LEN(host->tar_conf_opt) + 
 			LEN(ONEFILE) + 
 			LEN(MUTE) + 18 );
 
@@ -572,10 +576,11 @@ char * setup_tarcmd(phost_t host) {
 	comp = (char*) xmalloc( compmax_len + LEN(" | ") + 3); /* 3 = _-6 */
 
 	/* tar will always look like this */
-	sprintf(tar,"%s %s - %s --files-from %s --listed-incremental %s --exclude-from %s --ignore-failed-read",
+	sprintf(tar,"%s %s - %s --files-from %s --listed-incremental %s --exclude-from %s --ignore-failed-read %s",
 			host->tar, TAR_NONE, SPARSE,
 			host->filelist, host->inclist,
-			host->excludelist);
+			host->excludelist,
+			host->tar_conf_opt);
 
 	if ( strncmp(host->compression, TAR_GZIP, LEN(TAR_GZIP)) == 0 ) {
 		sprintf(comp," |%s -%s",GZIP_PROG, host->complevel);
@@ -669,11 +674,14 @@ char * setup_untarcmd(phost_t host, char * extractdir, char *extractfile, int co
 				strlen(extractdir) +
 				LEN(SPARSE) + 2 +
 				LEN(MUTE) + /* just in case */
+				LEN(host->tar_conf_opt) +
 				strlen("--incremental") + 
 				strlen("--ignore-failed-read") + 12) ;
 
-		sprintf(tar,"%s %s - %s %s %s --ignore-failed-read --incremental",
-				host->tar, UNTAR_OPT, extractdir, SPARSE, tar_opt);
+		/* Maybe here also tar_options... */
+		sprintf(tar,"%s %s - %s %s %s --ignore-failed-read %s --incremental",
+				host->tar, UNTAR_OPT, extractdir, SPARSE, tar_opt,
+				host->tar_conf_opt);
 	} else {
 		/* extract a single file */
 		tar = (char*) xmalloc(strlen(host->tar) +
@@ -682,13 +690,15 @@ char * setup_untarcmd(phost_t host, char * extractdir, char *extractfile, int co
 				strlen(extractdir) +
 				LEN(SPARSE) + 2 +
 				strlen(MUTE) + 
+				LEN(host->tar_conf_opt) + 
 				strlen("--incremental") + 
 				strlen("--ignore-failed-read") +
 				strlen(extractfile) + 12) ;
 
-		sprintf(tar,"%s %s - %s %s %s --ignore-failed-read --incremental %s",
+		sprintf(tar,"%s %s - %s %s %s --ignore-failed-read --incremental %s %s",
 				host->tar, UNTAR_OPT,  
-				extractdir, extractfile, SPARSE, tar_opt);
+				extractdir, extractfile, SPARSE, tar_opt,
+				host->tar_conf_opt);
 	}
 	if ( quiet > 0 )
 		strncat(tar, MUTE, strlen(MUTE));
